<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Yajra\DataTables\DataTables;
use App\Models\User;
use Illuminate\Support\Facades\Hash;


class BrokerController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = User::with('role','wallet')->where('role_id', 2)->select('users.*');

            return Datatables::of($data)
                ->addColumn('wallet', function ($row) {
                    return $row->wallet ? $row->wallet->amount : 'N/A';
                })
                ->addColumn('creditref_admin', function ($row) {
                    return $row->creditref_admin ? $row->creditref_admin : 'N/A';
                })
                ->addColumn('action', function ($row) {
                    return '<a href="' . route('admin.brokers.edit', $row->id) . '" class="btn btn-success btn-sm">Details</a>
                    <a href="' . route('admin.users.brokers', $row->id) . '" class="btn btn-success btn-sm">Broker Users</a>';
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.brokers.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.brokers.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|max:100',
            'username' => 'required|max:100|unique:users,username',
            'email' => ['required', 'string', 'email:rfc,dns', 'max:100', 'unique:' . User::class],
            'password' => 'required:min:6|max:12',
            // 'commission' => 'required|numeric',
            'singleamount' => 'required|numeric',
            'jodiamount' => 'required|numeric',
        ]);

        $user = User::create([
            'name' => $request->input('name'),
            'username' => $request->input('username'),
            'email' => $request->input('email'),
            'role_id' => 2,
            'password' => Hash::make($request->input('password')),
            // 'commission' => $request->input('commission'),
            'singleamount' => $request->input('singleamount'),
            'jodiamount' => $request->input('jodiamount'),
        ]);

        return back()->withInput()->with('success', 'Broker Created Successfully!.');
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $user = User::findOrFail($id);
        return view('admin.brokers.edit', compact('user'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            $user = User::findOrFail($id);

            $passwordValidation = ($request->has('password') && !empty($request->input('password'))) ? 'required|min:6|max:12' : 'nullable';

            $request->validate([
                'name' => 'required|max:100',
                'email' => ['required', 'string', 'email:rfc,dns', 'max:100', 'unique:users,email,' . $user->id],
                // 'commission' => 'required|numeric',
                'singleamount' => 'required|numeric',
                'jodiamount' => 'required|numeric',
                'password' => $passwordValidation,
                'status' => 'required',
            ]);

            $user->update([
                'name' => $request->input('name'),
                'email' => $request->input('email'),
                // 'commission' => $request->input('commission'),
                'singleamount' => $request->input('singleamount'),
                'jodiamount' => $request->input('jodiamount'),
                'password' => ($request->has('password') && !empty($request->input('password'))) ? Hash::make($request->input('password')) : $user->password,
                'status' => $request->input('status'),
            ]);


            return back()->withInput()->with('success', 'Broker Updated Successfully!.');
        } catch (ValidationException $e) {
            return redirect()->back()->withErrors($e->errors())->withInput();
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        //
    }

    public function updateCreditRef(Request $request, $id)
    {
        // Validate the incoming request
        $request->validate([
            'creditref' => 'required|string',
        ]);

        try {
            // Attempt to find the user by ID
            $customer = User::findOrFail($id);

            // Update the credit reference
            $customer->creditref_admin = $request->input('creditref');
            $customer->save();

            // Return a success response
            return response()->json([
                'success' => true,
                'message' => 'Credit Ref updated successfully.',
                'creditref' => $customer->creditref
            ]);
        } catch (\Illuminate\Database\Eloquent\ModelNotFoundException $e) {
            // If the customer is not found
            return response()->json([
                'success' => false,
                'message' => 'Customer not found.'
            ], 404);
        } catch (\Exception $e) {
            // Handle any other errors
            return response()->json([
                'success' => false,
                'message' => 'An error occurred while updating the Credit Ref. Please try again.',
            ], 500);
        }
    }
}
