<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Game;
use Yajra\DataTables\DataTables;

class GameController extends Controller
{
    public function index(Request $request)
    {
        if ($request->ajax()) {
            // $data = Game::select('games.*');
            $data = Game::select('games.*')->orderBy('id', 'desc');
            return DataTables::of($data)
                ->addColumn('action', function ($row) {
                    return '<a href="' . route('games.edit', $row->id) . '" class="btn btn-success btn-sm">Edit</a>';
                })
                ->editColumn('game_type', function ($row) {
                    return $row->game_type == 1 ? 'Single' : 'Jodi';
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        return view('admin.games.index');
    }

    public function create()
    {
        return view('admin.games.create');
    }

    public function edit($id)
    {
        // Fetch the game by ID. Use 'findOrFail' to throw a 404 error if the game is not found.
        $game = Game::findOrFail($id);

        // Return the edit view and pass the game data to it.
        return view('admin.games.edit', compact('game'));
    }

    public function store(Request $request)
    {
        $request->validate([
            'game_name' => 'required|string|max:255',
            'game_type' => 'required|in:1,2',
            'minimum_bet' => 'nullable|integer',
            'maximum_bet' => 'nullable|integer',
        ]);
        Game::create($request->all());
        return redirect()->route('games.index');
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $request->validate([
            'game_name' => 'required|string|max:255',
            'game_type' => 'required|in:1,2',
            'minimum_bet' => 'nullable|integer',
            'maximum_bet' => 'nullable|integer',
        ]);

        // Fetch the game by ID
        $game = Game::findOrFail($id);

        // Update the game data
        $game->update([
            'game_name' => $request->game_name,
            'game_type' => $request->game_type,
            'minimum_bet' => $request->minimum_bet,
            'maximum_bet' => $request->maximum_bet,
        ]);

        // Redirect to a specific route (e.g., the index view) with a success message
        return redirect()->route('games.index')
            ->with('success', 'Game updated successfully');
    }
}
