<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\Wallet;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Http\Request;

class WalletController extends Controller
{
    public function updateWallet(Request $request)
    {
        $userID = $request->input('user_id');
        $crefitRef = "";
        if($request->input('action') == "add"){
            $CR_ID = $userID;
            $DR_ID = Auth::id();
            $CR_User = User::find($userID);
            $CR_Name = $CR_User->username;
            $DR_Name = Auth::user()->username;
            $remark = "Amount Credited to $CR_Name from $DR_Name";
        }else{
            $CR_ID = Auth::id();
            $DR_ID = $userID;
            $DR_User = User::find($userID);
            $CR_Name = Auth::user()->username;
            $DR_Name = $DR_User->username;
            $remark = "Amount Debited from $DR_Name by $CR_Name";
        }

        if($request->has('creditref')){
            $crefitRef = $request->input('creditref');
        }
        $amount = $request->input('amount');

        if($amount == "" || !is_numeric($amount) || $amount <= 0){
            return response()->json(['message' => 'Enter Correct Amount.']);
        }

        $debitUser = User::find($DR_ID);
        if($debitUser->role_id != 1){
            $walletBalance = $debitUser->wallet()->sum('amount');
            if($amount > $walletBalance){
                return response()->json(['message' => 'Insufficient balance for this transaction']);
            }
        }


        // Perform debit and credit operations
        $debitWallet = $this->getOrCreateWallet($DR_ID);
        $creditWallet = $this->getOrCreateWallet($CR_ID);

        // Apply business logic to check for sufficient balance, etc.
        /*
        $debitWallet->amount -= $amount;
        $creditWallet->amount += $amount;
        */

        $debitWallet->amount = bcsub($debitWallet->amount, $amount, 2);
        $creditWallet->amount = bcadd($creditWallet->amount, $amount, 2);

        // Save the wallet updates
        $debitWallet->save();
        $creditWallet->save();

        if(!isset($remark)){
            $remark = "Wallet Transaction";
        }
        // Create a transaction record
        Transaction::create([
            'DR_ID' => $DR_ID,
            'CR_ID' => $CR_ID,
            'amount' => $amount,
            'creditref' => $crefitRef,
            'transaction_type' => "wallet",
            'remark' => $remark,
        ]);

        return response()->json(['message' => 'Transaction successful']);
    }
    private function getOrCreateWallet($userId) {
        return Wallet::firstOrCreate(['user_id' => $userId], ['amount' => 0]);
    }
}
