<?php

namespace App\Http\Controllers;

use App\Models\GameSession;
use App\Models\Bid;
use App\Models\BidNumber;
use App\Models\Bidding;
use App\Models\Transaction;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class BidController extends Controller
{
    public function show()
    {
        $now = now();
        $user = Auth::user();
        $activeSessions = GameSession::with('game') // Include game details
            ->whereHas('game', function ($query) {
                $query->where('game_type', 1); // Filter for single games
            })
            ->where('start_time', '<=', $now)
            ->whereNull('winning_number')
            ->get();

            $previousBidsSum = array();
        foreach ($activeSessions as $session) {
            // Calculate the total bids for this session by the current user
            $totalBidAmount = Bidding::where('user_id', Auth::id())
                ->where('game_session_id', $session->id)
                ->sum('total_amount');

            $session->totalUserBids = $totalBidAmount;


            // Other Working Code
            $previousBids = $user->totalBids()->where('game_session_id', $session->id)->get();
            foreach ($previousBids as $bid) {
                foreach (range(0, 99) as $number) {
                    $fieldName = "num_$number";
                    if (isset($bid->$fieldName)) {
                        if (!isset($previousBidsSum[$session->id])) {
                            $previousBidsSum[$session->id] = array_fill(0, 100, 0);;
                        }
                        $previousBidsSum[$session->id][$number] += $bid->$fieldName;
                    }
                }
            }
        }
        $previousBidsJson = json_encode($previousBidsSum);
        return view('single', compact('activeSessions', 'user', 'previousBidsJson'));
    }

    public function jodishow()
    {
        $now = now();
        $user = Auth::user();
        $activeSessions = GameSession::with('game') // Include game details
            ->whereHas('game', function ($query) {
                $query->where('game_type', 2); // Filter for single games
            })
            ->where('start_time', '<=', $now)
            ->whereNull('winning_number')
            ->get();

            $previousBidsSum = array();
        foreach ($activeSessions as $session) {
            // Calculate the total bids for this session by the current user
            $totalBidAmount = Bidding::where('user_id', Auth::id())
                ->where('game_session_id', $session->id)
                ->sum('total_amount');

            $session->totalUserBids = $totalBidAmount;

            $previousBids = $user->totalBids()->where('game_session_id', $session->id)->get();
            foreach ($previousBids as $bid) {
                foreach (range(0, 99) as $number) {
                    $fieldName = "num_$number";
                    if (isset($bid->$fieldName)) {
                        if (!isset($previousBidsSum[$session->id])) {
                            $previousBidsSum[$session->id] = array_fill(0, 100, 0);;
                        }
                        $previousBidsSum[$session->id][$number] += $bid->$fieldName;
                    }
                }
            }
        }

        $previousBidsJson = json_encode($previousBidsSum);

        return view('jodi', compact('activeSessions', 'user', 'previousBidsJson'));
    }

    // Place a bid
    public function store(Request $request)
    {
        if (!$request->ajax()) {
            return response()->json(['error' => 'Invalid request type'], 403);
        }
        // Validate the request
        $validated = $request->validate([
            'game_session_id' => 'required|integer',
            'bids.*' => 'required|numeric|min:0'
        ]);

        $currentUser = Auth::user();
        $gameSession = GameSession::find($request->game_session_id);

        if (!$gameSession) {
            return response()->json(['status' => false, 'message' => 'Game session not found']);
        }

        $now = now();
        if ($gameSession->end_time < $now) {
            return response()->json(['status' => false, 'message' => 'Cannot place bid. The game session has ended.']);
        }

        $totalBid = array_sum($request->bids ?? []);

        if ($currentUser->wallet()->sum('amount') < $totalBid) {
            return response()->json(['status' => false, 'message' => 'Insufficient wallet balance']);
        }

        $previousBids = $currentUser->totalBids()->where('game_session_id', $gameSession->id)->get();

        $previousBidsSum = [];
        foreach ($previousBids as $bid) {
            foreach (range(0, 99) as $number) {
                $fieldName = "num_$number";
                if (isset($bid->$fieldName)) {
                    if (!isset($previousBidsSum[$number])) {
                        $previousBidsSum[$number] = 0;
                    }
                    $previousBidsSum[$number] += $bid->$fieldName;
                }
            }
        }

        // Validate new bids against session limits and previous bids
        foreach ($request->bids as $number => $amount) {
            if ($number >= 0 && $number <= 99) {
                $maxBidLimit = $gameSession->maximum_bet; // Implement this method in GameSession model
                $totalForNumber = $amount + ($previousBidsSum[$number] ?? 0);

                if ($totalForNumber > $maxBidLimit) {
                    return response()->json([
                        'status' => false,
                        'message' => "Bid for number $number exceeds limit"
                    ]);
                }
            }
        }

        // You might want to add additional validation here to check
        // if the total bid exceeds any limits based on the game session

        // Store the bid
        $bidding = new Bidding();
        $bidding->user_id = Auth::id();
        $bidding->game_session_id = $request->game_session_id;
        $bidding->total_amount = $totalBid;
        foreach ($request->bids as $number => $amount) {
            if ($number >= 0 && $number <= 99) {
                $fieldName = "num_$number";
                $bidding->$fieldName = $amount;
            }
        }

        $brokerId = $currentUser->broker_id; // Assuming there is a 'broker_id' field in your users table
        // $broker = User::find($brokerId); // Retrieve the broker

        // if ($broker) {
        //     $commissionRate = $broker->commission; // Assuming 'commission' field stores the broker's commission rate
        //     $commissionAmount = $totalBid * ($commissionRate / 100); // Calculate the commission amount
        //     $bidding->commission = $commissionAmount; // Store the commission in the bidding
        // }

        $bidding->save();
        $currentUser->wallet->amount -= $totalBid;
        $currentUser->wallet->save();


        if($gameSession->game->game_type == 1){
            $gameType = "single";
        }elseif($gameSession->game->game_type == 2){
            $gameType = "jodi";
        }
        Transaction::create([
            'DR_ID' => Auth::id(), // Default value as indicated
            'CR_ID' => 1, // Assuming this represents the user ID for the credit transaction
            'amount' => $totalBid,
            'transaction_type' => 'debit',
            'remark' => "Bid for Game #{$gameSession->id} {$gameSession->game->game_name} ($gameType)"
        ]);
        return response()->json(['status' => true, 'message' => 'Bid successfully stored']);
    }
    public function store33(Request $request)
    {
        $validatedData = $request->validate([
            'game_session_id' => 'required|exists:game_sessions,id',
            'bids.*' => 'required|numeric|min:0', // Validate each bid amount
        ]);

        $gameSession = GameSession::find($request->game_session_id);
        $userId = Auth::id();
        $totalUserBids = Bid::where('user_id', $userId)
            ->where('game_session_id', $request->game_session_id)
            ->sum('amount'); // Assuming 'amount' stores the total bid amount for a session

        $newTotalBid = array_sum($request->bids) + $totalUserBids;

        if ($newTotalBid > $gameSession->maximum_bid) {
            return response()->json(['error' => 'Total bid exceeds maximum allowed amount'], 400);
        }

        // Save the bid data
        foreach ($request->bids as $number => $amount) {
            Bid::create([
                'user_id' => $userId,
                'game_session_id' => $request->game_session_id,
                'number' => $number,
                'amount' => $amount,
                // 'status' => 'pending' // Or any default status
            ]);
        }

        return response()->json(['success' => 'Bid submitted successfully']);
    }

    // Show bid history for the logged-in user
    public function history()
    {
        $bids = Bid::where('user_id', auth()->id())->with('bidNumbers')->get();
        return view('bets.history', compact('bids'));
    }

    public function biddingHistory()
    {
        if (request()->ajax()) {
            $data = Bidding::where('user_id', auth()->id()); // Fetch biddings for the logged-in user

            return DataTables::of($data)
                ->addColumn('action', function ($row) {
                    // Modify as needed
                    return '<a href="#edit-' . $row->id . '" class="btn btn-success btn-sm">Edit</a>';
                })
                ->make(true);
        }

        return view('customer.bidding.history');
    }
}
