<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Yajra\DataTables\Facades\DataTables;
use App\Models\Transaction;
use Illuminate\Support\Facades\DB;

class CustomerDashboardController extends Controller
{
    public function index()
    {
        $user = Auth::user();
        $now = now();
        $walletBalance = $user->wallet()->sum('amount');
        $totalBids = $user->totalBids()->count();
        $totalDeposits = $user->totalDeposits();
        $totalWithdraws = $user->totalWithdraws();
        $totalActiveBetsAmount = $user->totalBids()->whereHas('gameSession', function ($query) {
            $now = now();
            $query->where('start_time', '<=', $now)
                ->whereNull('winning_number');
        })->sum('total_amount');
        $totalActiveBets = $user->totalBids()->whereHas('gameSession', function ($query) {
            $now = now();
            $query->where('start_time', '<=', $now)
                ->whereNull('winning_number');
        })->count();



        return view('customer.dashboard', compact('user', 'walletBalance', 'totalBids', 'totalDeposits', 'totalWithdraws', 'totalActiveBetsAmount', 'totalActiveBets'));
    }
    public function wallet()
    {
        $user = Auth::user();
        $walletBalance = $user->wallet()->sum('amount');
        return view('customer.wallet', compact('user', 'walletBalance'));
    }

    public function account()
    {
        $user = Auth::user();
        return view('customer.account', compact('user'));
    }
    public function totalExposure()
    {
        $now = now();

        // Fetch active game sessions that are currently ongoing
        $activeSessions = GameSession::with('game')
            ->where('start_time', '<=', $now)
            ->where('end_time', '>=', $now)
            ->get();

        // Initialize total amount of active bets
        $totalActiveBets = 0;

        foreach ($activeSessions as $session) {
            // Sum up the total bids placed on each active session across all users
            $sessionBidsTotal = Bidding::where('game_session_id', $session->id)
                ->sum('total_amount');

            // Accumulate into total active bets
            $totalActiveBets += $sessionBidsTotal;
        }

        // Pass the total active bets to the view
        return view('dashboard', ['totalActiveBets' => $totalActiveBets]);
    }
    public function biddinghistory(Request $request)
    {
        if (request()->ajax()) {
            $user = Auth::user();
            $query = $user->totalBids()->with([
                'gameSession' => function ($query) {
                    $query->with('game');
                }
            ])->orderBy('created_at', 'desc');

            if (!empty($request->start_date) && !empty($request->end_date)) {
                $startDate = $request->start_date;
                $endDate = $request->end_date;
                $query->whereBetween('created_at', [$startDate, $endDate]);
            }

            return DataTables::of($query)
                ->addColumn('game', function ($row) {
                    return $row->gameSession->game->game_name ?? 'N/A';
                })
                ->addColumn('session', function ($row) {
                    return $row->gameSession->id ?? 'N/A';
                })
                ->addColumn('bid_details', function ($row) {
                    $gameType = $row->gameSession->game->game_type ?? null;
                    $bidDetails = '<div class="bid-details-container">';

                    if ($gameType == 1) {
                        // Single bid data format
                        $bidDetails .= '<div class="andar-bids">';
                        $bidDetails .= '<div class="bid-category-title">Andar</div>';
                        for ($i = 0; $i <= 9; $i++) {
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($amount == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                        $bidDetails .= '</div>'; // Close andar-bids

                        $bidDetails .= '<div class="bahar-bids">';
                        $bidDetails .= '<div class="bid-category-title">Bahar</div>';
                        for ($i = 10; $i <= 19; $i++) {
                            $actNum = $i - 10;
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($amount == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $actNum . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                        $bidDetails .= '</div>'; // Close bahar-bids
                    } elseif ($gameType == 2) {
                        // Jodi bid data format
                        for ($i = 0; $i <= 99; $i++) {
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($row->$column == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                    }

                    $bidDetails .= '</div>';
                    return $bidDetails;
                })
                ->editColumn('total_amount', function ($row) {
                    return $row->total_amount ?? 0;
                })
                ->editColumn('created_at', function ($row) {
                    return $row->created_at->toDateString(); // Adjust the format as necessary
                })
                ->rawColumns(['game', 'bid_details'])
                ->make(true);
        }

        return view('customer.biddinghistory');
    }

    public function activebiddinghistory()
    {
        if (request()->ajax()) {
            $user = Auth::user();
            $query = $user->totalBids()
                ->whereHas('gameSession', function ($query) {
                    $now = now();
                    $query->where('start_time', '<=', $now)
                        ->where('end_time', '>=', $now);
                })
                ->with([
                    'gameSession' => function ($query) {
                        $query->with('game');
                    }
                ])
                ->orderBy('created_at', 'desc');
            return DataTables::of($query)
                ->addColumn('game', function ($row) {
                    return $row->gameSession->game->game_name ?? 'N/A';
                })
                ->addColumn('session', function ($row) {
                    return $row->gameSession->id ?? 'N/A';
                })
                ->addColumn('bid_details', function ($row) {
                    $gameType = $row->gameSession->game->game_type ?? null;
                    $bidDetails = '<div class="bid-details-container">';

                    if ($gameType == 1) {
                        // Single bid data format
                        $bidDetails .= '<div class="andar-bids">';
                        $bidDetails .= '<div class="bid-category-title">Andar</div>';
                        for ($i = 0; $i <= 9; $i++) {
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($amount == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                        $bidDetails .= '</div>'; // Close andar-bids

                        $bidDetails .= '<div class="bahar-bids">';
                        $bidDetails .= '<div class="bid-category-title">Bahar</div>';
                        for ($i = 10; $i <= 19; $i++) {
                            $actNum = $i - 10;
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($amount == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $actNum . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                        $bidDetails .= '</div>'; // Close bahar-bids
                    } elseif ($gameType == 2) {
                        // Jodi bid data format
                        for ($i = 0; $i <= 99; $i++) {
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($row->$column == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                    }

                    $bidDetails .= '</div>';
                    return $bidDetails;
                })
                ->editColumn('total_amount', function ($row) {
                    return $row->total_amount ?? 0;
                })
                ->editColumn('created_at', function ($row) {
                    return $row->created_at->toDateString(); // Adjust the format as necessary
                })
                ->rawColumns(['game', 'bid_details'])
                ->make(true);
        }

        return view('customer.activebiddinghistory');
    }

    public function profitAndLoss_old()
    {
        if (request()->ajax()) {
            $user = Auth::user();
            $query = $user->totalBids()->with([
                'gameSession' => function ($query) {
                    $query->with('game');
                }
            ])->orderBy('created_at', 'desc');

            return DataTables::of($query)
                ->addColumn('game', function ($row) {
                    return $row->gameSession->game->game_name ?? 'N/A';
                })
                ->addColumn('session', function ($row) {
                    $winningNumber = $row->gameSession->winning_number ?? 'N/A';
                    if (is_numeric($row->gameSession->winning_number) && $row->gameSession->winning_number < 10) {
                        $winningNumber = sprintf("%02d", $row->gameSession->winning_number);
                    }
                    return $winningNumber;
                })
                ->addColumn('bid_details', function ($row) {
                    $gameType = $row->gameSession->game->game_type ?? null;
                    $bidDetails = '<div class="bid-details-container">';

                    if ($gameType == 1) {
                        // Single bid data format
                        $bidDetails .= '<div class="andar-bids">';
                        $bidDetails .= '<div class="bid-category-title">Andar</div>';
                        for ($i = 0; $i <= 9; $i++) {
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($amount == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                        $bidDetails .= '</div>'; // Close andar-bids

                        $bidDetails .= '<div class="bahar-bids">';
                        $bidDetails .= '<div class="bid-category-title">Bahar</div>';
                        for ($i = 10; $i <= 19; $i++) {
                            $actNum = $i - 10;
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($amount == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $actNum . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                        $bidDetails .= '</div>'; // Close bahar-bids
                    } elseif ($gameType == 2) {
                        // Jodi bid data format
                        for ($i = 0; $i <= 99; $i++) {
                            $column = 'num_' . $i;
                            $amount = $row->$column;
                            if ($row->$column == 0) {
                                continue;
                            }
                            $bidDetails .= '<div class="bid-detail">';
                            $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                            $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                            $bidDetails .= '</div>';
                        }
                    }

                    $bidDetails .= '</div>';
                    return $bidDetails;
                })
                ->addColumn('profit_loss', function ($row) {

                    $totalProfit = 0;
                    $totalLoss = 0;
                    $winningNumber = $row->gameSession->winning_number ?? null;
                    $gameType = $row->gameSession->game->game_type ?? null;
                    $singleAmount = $row->user->singleamount ?? 0;
                    $jodiAmount = $row->user->jodiamount ?? 0;
                    $winCal = 0;
                    if ($winningNumber !== null && $gameType !== null) {
                        if ($gameType == 1) {
                            // Andar Bahar game type
                            if ($winningNumber < 10) {
                                $winningNumber = sprintf("%02d", $winningNumber);
                            }
                            $andar = intval($winningNumber[0]); // First digit
                            $bahar = intval($winningNumber[1]); // Second digit
                            $totalProfit += ($row->{'num_' . $andar} ?? 0) + ($row->{'num_' . ($bahar + 10)} ?? 0);

                            for ($i = 0; $i <= 9; $i++) {
                                $totalLoss += $row->{'num_' . $i} ?? 0;
                            }
                            for ($i = 10; $i <= 19; $i++) {
                                $totalLoss += $row->{'num_' . $i} ?? 0;
                            }
                            $winCal = $singleAmount;
                        } elseif ($gameType == 2) {
                            // Jodi game type
                            $totalProfit += $row->{'num_' . $winningNumber} ?? 0;
                            for ($i = 0; $i <= 99; $i++) {
                                $totalLoss += $row->{'num_' . $i} ?? 0;
                            }
                            $winCal = $jodiAmount;
                        }
                    }


                    $netProfitLoss = $totalProfit - $totalLoss;
                    $finalprofit = $winCal * $totalProfit;

                    $finalp = $finalprofit > 0 ? $finalprofit / 10 : 0;

                    $finaluserresult = $finalp - abs($netProfitLoss);
                    if ($finaluserresult > 0) {
                        $class = "text-success";
                    } else {
                        $class = "text-danger";
                    }
                    $html = "<div class='profit-loss'>";
                    $html .= "<div class='" . $class . "'>" . number_format($finaluserresult, 2) . "</div>";

                    // $html .= "<div class='profit'>Profit: " . number_format($finalprofit/10, 2) . "</div>";
                    // $html .= "<div class='loss'>Loss: " . number_format($netProfitLoss, 2) . "</div>";

                    $html .= "</div>";


                    return $html;
                })
                ->editColumn('total_amount', function ($row) {
                    return $row->total_amount ?? 0;
                })
                ->editColumn('created_at', function ($row) {
                    return $row->created_at->toDateString(); // Adjust the format as necessary
                })
                ->rawColumns(['game', 'bid_details', 'profit_loss'])
                ->make(true);
        }

        return view('customer.profitloss');
    }


    public function profitAndLoss()
    {
        if (request()->ajax()) {
            $userId = Auth::id();

            // Build the query to aggregate bids by game session
            $query = DB::table('bidding')
                ->select(
                    'bidding.game_session_id',
                    'game_sessions.winning_number',
                    'games.game_name',
                    'games.game_type',
                    'game_sessions.created_at',
                    DB::raw('SUM(bidding.num_0) as num_0'),
                    DB::raw('SUM(bidding.num_1) as num_1'),
                    DB::raw('SUM(bidding.num_2) as num_2'),
                    DB::raw('SUM(bidding.num_3) as num_3'),
                    DB::raw('SUM(bidding.num_4) as num_4'),
                    DB::raw('SUM(bidding.num_5) as num_5'),
                    DB::raw('SUM(bidding.num_6) as num_6'),
                    DB::raw('SUM(bidding.num_7) as num_7'),
                    DB::raw('SUM(bidding.num_8) as num_8'),
                    DB::raw('SUM(bidding.num_9) as num_9'),
                    DB::raw('SUM(bidding.num_10) as num_10'),
                    DB::raw('SUM(bidding.num_11) as num_11'),
                    DB::raw('SUM(bidding.num_12) as num_12'),
                    DB::raw('SUM(bidding.num_13) as num_13'),
                    DB::raw('SUM(bidding.num_14) as num_14'),
                    DB::raw('SUM(bidding.num_15) as num_15'),
                    DB::raw('SUM(bidding.num_16) as num_16'),
                    DB::raw('SUM(bidding.num_17) as num_17'),
                    DB::raw('SUM(bidding.num_18) as num_18'),
                    DB::raw('SUM(bidding.num_19) as num_19'),
                    DB::raw('SUM(bidding.num_20) as num_20'),
                    DB::raw('SUM(bidding.num_21) as num_21'),
                    DB::raw('SUM(bidding.num_22) as num_22'),
                    DB::raw('SUM(bidding.num_23) as num_23'),
                    DB::raw('SUM(bidding.num_24) as num_24'),
                    DB::raw('SUM(bidding.num_25) as num_25'),
                    DB::raw('SUM(bidding.num_26) as num_26'),
                    DB::raw('SUM(bidding.num_27) as num_27'),
                    DB::raw('SUM(bidding.num_28) as num_28'),
                    DB::raw('SUM(bidding.num_29) as num_29'),
                    DB::raw('SUM(bidding.num_30) as num_30'),
                    DB::raw('SUM(bidding.num_31) as num_31'),
                    DB::raw('SUM(bidding.num_32) as num_32'),
                    DB::raw('SUM(bidding.num_33) as num_33'),
                    DB::raw('SUM(bidding.num_34) as num_34'),
                    DB::raw('SUM(bidding.num_35) as num_35'),
                    DB::raw('SUM(bidding.num_36) as num_36'),
                    DB::raw('SUM(bidding.num_37) as num_37'),
                    DB::raw('SUM(bidding.num_38) as num_38'),
                    DB::raw('SUM(bidding.num_39) as num_39'),
                    DB::raw('SUM(bidding.num_40) as num_40'),
                    DB::raw('SUM(bidding.num_41) as num_41'),
                    DB::raw('SUM(bidding.num_42) as num_42'),
                    DB::raw('SUM(bidding.num_43) as num_43'),
                    DB::raw('SUM(bidding.num_44) as num_44'),
                    DB::raw('SUM(bidding.num_45) as num_45'),
                    DB::raw('SUM(bidding.num_46) as num_46'),
                    DB::raw('SUM(bidding.num_47) as num_47'),
                    DB::raw('SUM(bidding.num_48) as num_48'),
                    DB::raw('SUM(bidding.num_49) as num_49'),
                    DB::raw('SUM(bidding.num_50) as num_50'),
                    DB::raw('SUM(bidding.num_51) as num_51'),
                    DB::raw('SUM(bidding.num_52) as num_52'),
                    DB::raw('SUM(bidding.num_53) as num_53'),
                    DB::raw('SUM(bidding.num_54) as num_54'),
                    DB::raw('SUM(bidding.num_55) as num_55'),
                    DB::raw('SUM(bidding.num_56) as num_56'),
                    DB::raw('SUM(bidding.num_57) as num_57'),
                    DB::raw('SUM(bidding.num_58) as num_58'),
                    DB::raw('SUM(bidding.num_59) as num_59'),
                    DB::raw('SUM(bidding.num_60) as num_60'),
                    DB::raw('SUM(bidding.num_61) as num_61'),
                    DB::raw('SUM(bidding.num_62) as num_62'),
                    DB::raw('SUM(bidding.num_63) as num_63'),
                    DB::raw('SUM(bidding.num_64) as num_64'),
                    DB::raw('SUM(bidding.num_65) as num_65'),
                    DB::raw('SUM(bidding.num_66) as num_66'),
                    DB::raw('SUM(bidding.num_67) as num_67'),
                    DB::raw('SUM(bidding.num_68) as num_68'),
                    DB::raw('SUM(bidding.num_69) as num_69'),
                    DB::raw('SUM(bidding.num_70) as num_70'),
                    DB::raw('SUM(bidding.num_71) as num_71'),
                    DB::raw('SUM(bidding.num_72) as num_72'),
                    DB::raw('SUM(bidding.num_73) as num_73'),
                    DB::raw('SUM(bidding.num_74) as num_74'),
                    DB::raw('SUM(bidding.num_75) as num_75'),
                    DB::raw('SUM(bidding.num_76) as num_76'),
                    DB::raw('SUM(bidding.num_77) as num_77'),
                    DB::raw('SUM(bidding.num_78) as num_78'),
                    DB::raw('SUM(bidding.num_79) as num_79'),
                    DB::raw('SUM(bidding.num_80) as num_80'),
                    DB::raw('SUM(bidding.num_81) as num_81'),
                    DB::raw('SUM(bidding.num_82) as num_82'),
                    DB::raw('SUM(bidding.num_83) as num_83'),
                    DB::raw('SUM(bidding.num_84) as num_84'),
                    DB::raw('SUM(bidding.num_85) as num_85'),
                    DB::raw('SUM(bidding.num_86) as num_86'),
                    DB::raw('SUM(bidding.num_87) as num_87'),
                    DB::raw('SUM(bidding.num_88) as num_88'),
                    DB::raw('SUM(bidding.num_89) as num_89'),
                    DB::raw('SUM(bidding.num_90) as num_90'),
                    DB::raw('SUM(bidding.num_91) as num_91'),
                    DB::raw('SUM(bidding.num_92) as num_92'),
                    DB::raw('SUM(bidding.num_93) as num_93'),
                    DB::raw('SUM(bidding.num_94) as num_94'),
                    DB::raw('SUM(bidding.num_95) as num_95'),
                    DB::raw('SUM(bidding.num_96) as num_96'),
                    DB::raw('SUM(bidding.num_97) as num_97'),
                    DB::raw('SUM(bidding.num_98) as num_98'),
                    DB::raw('SUM(bidding.num_99) as num_99'),
                    DB::raw('SUM(bidding.total_amount) as total_amount'),
                )
                ->join('game_sessions', 'bidding.game_session_id', '=', 'game_sessions.id')
                ->join('games', 'game_sessions.game_id', '=', 'games.id')
                ->where('bidding.user_id', $userId)
                ->groupBy(
                    'bidding.game_session_id',
                    'game_sessions.winning_number',
                    'games.game_name',
                    'games.game_type',
                    'game_sessions.created_at',
                )
                ->orderBy('game_sessions.created_at', 'desc');

            $results = $query->get();

            // Process the results to calculate profit and loss
            $results = $results->map(function ($row) use ($userId) {
                $singleAmount = DB::table('users')
                    ->where('id', $userId)
                    ->value('singleamount');

                $jodiAmount = DB::table('users')
                    ->where('id', $userId)
                    ->value('jodiamount');

                $totalProfit = 0;
                $totalLoss = 0;
                $winningNumber = $row->winning_number ?? null;
                $gameType = $row->game_type ?? null;
                $winCal = 0;

                if ($winningNumber !== null && $gameType !== null) {
                    if ($gameType == 1) {
                        // Andar Bahar game type
                        if ($winningNumber < 10) {
                            $winningNumber = sprintf("%02d", $winningNumber);
                        } else {
                            $winningNumber = strval($winningNumber);
                        }

                        $andar = intval($winningNumber[0]); // First digit
                        $bahar = intval($winningNumber[1]); // Second digit
                        $totalProfit += ($row->{'num_' . $andar} ?? 0) + ($row->{'num_' . ($bahar + 10)} ?? 0);


                        for ($i = 0; $i <= 9; $i++) {
                            $totalLoss += $row->{'num_' . $i} ?? 0;
                        }
                        for ($i = 10; $i <= 19; $i++) {
                            $totalLoss += $row->{'num_' . $i} ?? 0;
                        }
                        $winCal = $singleAmount;
                    } elseif ($gameType == 2) {
                        // Jodi game type
                        $totalProfit += $row->{'num_' . $winningNumber} ?? 0;
                        for ($i = 0; $i <= 99; $i++) {
                            $totalLoss += $row->{'num_' . $i} ?? 0;
                        }
                        $winCal = $jodiAmount;
                    }
                }

                $netProfitLoss = $totalProfit - $totalLoss;
                $finalProfit = $winCal * $totalProfit;
                $finalP = $finalProfit > 0 ? $finalProfit / 10 : 0;
                $finalUserResult = $finalP - abs($netProfitLoss);

                $class = $finalUserResult > 0 ? "text-success" : "text-danger";
                $profitLossHtml = "<div class='profit-loss'><div class='" . $class . "'>" . number_format($finalUserResult, 2) . "</div></div>";

                return (object) [
                    'id' => $row->game_session_id,
                    'game' => $row->game_name ?? 'N/A',
                    'session' => $row->winning_number ?? 'N/A',
                    'bid_details' => $this->getBidDetails($row, $gameType),
                    'profit_loss' => $profitLossHtml,
                    'total_amount' => $row->total_amount ?? 0,
                    'created_at' => $row->created_at // Adjust the format as necessary
                ];
            });

            return DataTables::of($results)
                ->rawColumns(['game', 'bid_details', 'profit_loss'])
                ->make(true);
        }

        return view('customer.profitloss');
    }

    private function getBidDetails($row, $gameType)
    {
        $bidDetails = '<div class="bid-details-container">';

        if ($gameType == 1) {
            // Single bid data format
            $bidDetails .= '<div class="andar-bids">';
            $bidDetails .= '<div class="bid-category-title">Andar</div>';
            for ($i = 0; $i <= 9; $i++) {
                $column = 'num_' . $i;
                $amount = $row->$column;
                if ($amount == 0) {
                    continue;
                }
                $bidDetails .= '<div class="bid-detail">';
                $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                $bidDetails .= '</div>';
            }
            $bidDetails .= '</div>'; // Close andar-bids

            $bidDetails .= '<div class="bahar-bids">';
            $bidDetails .= '<div class="bid-category-title">Bahar</div>';
            for ($i = 10; $i <= 19; $i++) {
                $actNum = $i - 10;
                $column = 'num_' . $i;
                $amount = $row->$column;
                if ($amount == 0) {
                    continue;
                }
                $bidDetails .= '<div class="bid-detail">';
                $bidDetails .= '<div class="bid-number">' . $actNum . '</div>';
                $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                $bidDetails .= '</div>';
            }
            $bidDetails .= '</div>'; // Close bahar-bids
        } elseif ($gameType == 2) {
            // Jodi bid data format
            for ($i = 0; $i <= 99; $i++) {
                $column = 'num_' . $i;
                $amount = $row->$column;
                if ($row->$column == 0) {
                    continue;
                }
                $bidDetails .= '<div class="bid-detail">';
                $bidDetails .= '<div class="bid-number">' . $i . '</div>';
                $bidDetails .= '<div class="bid-amount">' . ($amount > 0 ? $amount : '0') . '</div>';
                $bidDetails .= '</div>';
            }
        }

        $bidDetails .= '</div>';
        return $bidDetails;
    }


    public function deposithistory()
    {
        if (request()->ajax()) {
            $deposits = Auth::user()->depositHistory(); // Fetching deposit history

            return DataTables::of($deposits)
                ->editColumn('amount', function ($deposit) {
                    return number_format($deposit->amount, 2); // Format the amount
                })
                ->editColumn('created_at', function ($deposit) {
                    return $deposit->created_at->format('Y-m-d H:i:s'); // Format the date
                })
                ->make(true);
        }

        return view('customer.deposithistory');
    }

    public function withdrawhistory()
    {
        if (request()->ajax()) {
            $withdraws = Auth::user()->withdrawhistory(); // Fetching deposit history

            return DataTables::of($withdraws)
                ->editColumn('amount', function ($withdraw) {
                    return number_format($withdraw->amount, 2); // Format the amount
                })
                ->editColumn('created_at', function ($withdraw) {
                    return $withdraw->created_at->format('Y-m-d H:i:s'); // Format the date
                })
                ->make(true);
        }

        return view('customer.withdrawhistory');
    }


    public function transactionHistory()
    {
        if (request()->ajax()) {
            $userId = Auth::id(); // Get the currently authenticated user's ID

            // Fetch transactions where the user is either debtor or creditor
            $transactions = Transaction::where(function ($query) use ($userId) {
                $query->where('DR_ID', $userId)
                    ->orWhere('CR_ID', $userId);
            })
            ->orderBy('id', 'desc')
            ->get();

            return DataTables::of($transactions)
                ->editColumn('amount', function ($transaction) {
                    // Assuming 'amount' is a field in your transactions table
                    return number_format($transaction->amount, 2);
                })
                ->editColumn('created_at', function ($transaction) {
                    return $transaction->created_at->format('Y-m-d H:i:s');
                })
                ->addColumn('transaction_type', function ($transaction) use ($userId) {

                    return $transaction->DR_ID == $userId ? 'DEBIT' : 'CREDIT';
                })
                ->addColumn('remark', function ($transaction) {
                    // Add the remark field to the table
                    return $transaction->remark;
                })
                ->make(true);
        }

        return view('customer.transactionHistory');
    }


    public function resetPassword(Request $request)
    {
        $request->validate([
            'current_password' => 'required',
            'new_password' => 'required|min:8|confirmed',
        ]);

        $user = Auth::user();

        if (!Hash::check($request->current_password, $user->password)) {
            return redirect()->back()->withErrors(['current_password' => 'Current password is incorrect']);
        }

        $user->password = Hash::make($request->new_password);
        $user->save();

        return redirect()->route('customer.show-reset-password-form')->with('status', 'Password successfully updated');
    }

    public function getUserTransactions()
    {
        $userId = Auth::id();  // Get the currently authenticated user's ID

        // Query to fetch transactions where the current user is either the debtor or creditor
        $transactions = Transaction::where(function ($query) use ($userId) {
            $query->where('DR_ID', $userId)
                ->orWhere('CR_ID', $userId);
        })->get();

        return view('transactions.index', compact('transactions'));
    }


    public function showResetPasswordForm()
    {
        return view('customer.resetpassword');
    }
}
