<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\WithdrawalRequest;
use App\Models\Wallet;

use Illuminate\Http\Request;

class WithdrawalRequestController extends Controller
{

    public function showRequests()
    {
        if (request()->ajax()) {
            $requests = WithdrawalRequest::join('users', 'withdraw_request.user_id', '=', 'users.id')
                ->where('users.broker_id', auth()->id()) // Ensure users.broker_id matches the current broker's ID
                ->select([
                    'withdraw_request.id',
                    'users.username',
                    'withdraw_request.amount',
                    'withdraw_request.status',
                    'withdraw_request.created_at'
                ])
                ->get();

            return datatables()->of($requests)
                ->addColumn('action', function ($request) {
                    if ($request->status === 'pending') {
                        $approveBtn = '<button class="btn btn-success btn-sm approve" data-id="' . $request->request_id . '">Approve</button>';
                        $rejectBtn = '<button class="btn btn-danger btn-sm reject" data-id="' . $request->request_id . '">Reject</button>';
                        return $approveBtn . ' ' . $rejectBtn;
                    }
                    return '';
                })
                ->rawColumns(['action']) // Ensure HTML in the 'action' column is not escaped
                ->make(true);
        }

        return view('broker.withdrawalrequests');
    }

    public function approve($id)
    {
        $request = WithdrawalRequest::find($id);
        $request->status = 'approved';
        $request->save();

        return response()->json(['message' => 'Request approved successfully']);
    }

    public function reject($id)
    {
        $request = WithdrawalRequest::find($id);
        $request->status = 'rejected';
        $request->save();

        return response()->json(['message' => 'Request rejected successfully']);
    }


    public function createWithdrawRequest(Request $request)
    {
        $request->validate([
            'amount' => 'required|numeric|min:0.01', // Ensure the amount is positive and at least 0.01
        ]);

        $brokerId = auth()->id();
        $amountRequested = $request->amount;

        // Assuming you have a method to get the broker's current balance
        $currentBalance = $this->getBrokerBalance($brokerId);

        if ($amountRequested > $currentBalance) {
            return response()->json(['message' => 'Insufficient funds'], 422);
        }

        // Create the withdrawal request
        $withdrawalRequest = new WithdrawalRequest([
            'user_id' => $brokerId,
            'amount' => $amountRequested,
            'status' => 'pending', // Assuming new requests are marked as pending
        ]);
        $withdrawalRequest->save();

        return response()->json(['message' => 'Withdrawal request created successfully', 'data' => $withdrawalRequest], 201);
    }

    // Example helper method to get the broker's current balance
    protected function getBrokerBalance($brokerId)
    {
        $wallet = Wallet::where('user_id', $brokerId)->first();

        return $wallet ? $wallet->balance : 0.00;
    }
}
