<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens, HasFactory, Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'username',
        'email',
        'password',
        'role_id',
        'broker_id',
        'commission',
        'singleamount',
        'jodiamount',
        'status'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
        'password' => 'hashed',
    ];


    public function role()
    {
        return $this->belongsTo(Role::class);
    }

    public function customers()
    {
        return $this->hasMany(User::class, 'broker_id')->where('role_id', 3);
    }

    public function totalCommissionEarned()
    {
        $customers = $this->customers;

        $totalCommission = 0;
        foreach ($customers as $customer) {
            // Assuming there's a 'commission' field in each bid and a method totalBids() that fetches the bids
            $totalCommission += $customer->totalBids()->sum('commission');
        }

        return $totalCommission;
    }


    public function wallet()
    {
        // return $this->hasOne(Wallet::class)->first()->amount ?? 0;
        return $this->hasOne(Wallet::class);
    }

    public function biddingHistory()
    {
        // Assuming there's a 'bids' table with a 'user_id' foreign key
        return $this->hasMany(Bid::class)->get();
    }

    public function depositHistory()
    {
        return $this->hasMany(Transaction::class, 'CR_ID')->where('transaction_type', 'wallet');
    }

    public function withdrawHistory()
    {
        return $this->hasMany(Transaction::class, 'DR_ID')->where('transaction_type', 'wallet');
    }

    public function commissionWithdraw()
    {
        return $this->hasMany(Transaction::class, 'CR_ID')->where('transaction_type', 'cwallet');
    }

    public function totalBids()
    {
        return $this->hasMany(Bidding::class);
    }
    public function transactionsAsDebtor()
    {
        return $this->hasMany(Transaction::class, 'DR_ID');
    }

    public function transactionsAsCreditor()
    {
        return $this->hasMany(Transaction::class, 'CR_ID');
    }
    public function totalDeposits()
    {
        return $this->transactionsAsCreditor()->where('transaction_type', 'wallet')->sum('amount');
    }

    public function totalWithdraws()
    {
        return $this->transactionsAsDebtor()->where('transaction_type', 'wallet')->sum('amount');
    }

    public function transferCommissionToWallet()
    {
        $wallet = $this->wallet;
        $commissionEarned = (float)$this->totalCommissionEarned(); // Cast to float
        $withdrawCommission = (float)$this->commissionWithdraw()->sum('amount'); // Cast to float
        $pendingCommision = (float)($commissionEarned - $withdrawCommission); // Ensure this is a float

        if (!$wallet) {
            // Handle the case where the user doesn't have a wallet yet.
            return false;
        }

        // Add the pending commission to the wallet amount (ensure decimals are handled).
        $wallet->amount = (float)$wallet->amount + $pendingCommision;

        $wallet->save();

        Transaction::create([
            'DR_ID' => $this->id,
            'CR_ID' => $this->id, // Credit the user's account
            'amount' => $pendingCommision, // Ensure this is stored as a decimal
            'transaction_type' => "cwallet",
            'remark' => "Commission Transfer to $this->username of amount $pendingCommision"
        ]);

        return true;
    }


    public function exposure()
    {
        return $this->totalBids()->whereHas('gameSession', function ($query) {
            $now = now();
            $query->where('start_time', '<=', $now)
                ->whereNull('winning_number');
        });
    }
}
